SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = public, pg_catalog;

CREATE SEQUENCE setting.cc_cfg_xcloud_instance_id_sequence INCREMENT 1 MINVALUE 0 MAXVALUE 999999 START 0 CYCLE;

CREATE TABLE IF NOT EXISTS setting.cc_cfg_xcloud_platform (
    cloud_platform_id varchar(64) NOT NULL,
    cloud_platform_name varchar(256) NOT NULL,
    description varchar(256)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_platform
    ADD CONSTRAINT p_key_cc_cfg_xcloud_platform PRIMARY KEY (cloud_platform_id);

CREATE TABLE IF NOT EXISTS setting.cc_cfg_xcloud_scope (
    cloud_platform_id varchar(64) NOT NULL,
    cloud_scope_id varchar(64) NOT NULL,
    cloud_scope_name varchar(256) NOT NULL,
    owner_role_id varchar(64) NOT NULL,
    description varchar(256),
    cloud_type varchar(64) NOT NULL,
    billing_detail_collector_flg smallint,
    retention_period smallint,
    billing_last_date timestamp without time zone,
    account_id varchar(1024),
    reg_date timestamp without time zone,
    update_date timestamp without time zone,
    reg_user varchar(64),
    update_user varchar(64)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_scope
    ADD CONSTRAINT p_key_cc_cfg_xcloud_scope PRIMARY KEY (cloud_scope_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_scope
    ADD CONSTRAINT f_key_cc_cfg_xcloud_scope_cloud_platform_id FOREIGN KEY (cloud_platform_id) REFERENCES setting.cc_cfg_xcloud_platform(cloud_platform_id) ON DELETE CASCADE;

CREATE TABLE IF NOT EXISTS setting.cc_cfg_xcloud_scope_eprop (
    cloud_scope_id varchar(64) NOT NULL,
    name varchar(128) NOT NULL,
    data_type varchar(32),
    value varchar(256)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_scope_eprop
    ADD CONSTRAINT p_key_cc_cfg_xcloud_scope_eprop PRIMARY KEY (cloud_scope_id, name);
ALTER TABLE ONLY setting.cc_cfg_xcloud_scope_eprop
    ADD CONSTRAINT f_key_cc_cfg_cc_cfg_xcloud_scope_eprop_cloud_scope_id FOREIGN KEY (cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_scope(cloud_scope_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_facility_addtion (
    facility_id varchar(512) NOT NULL,
    cloud_scope_id varchar(64) NOT NULL,
    type varchar(256)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_facility_addtion
    ADD CONSTRAINT p_key_cc_cfg_xcloud_facility_addtion PRIMARY KEY (facility_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_facility_addtion
    ADD CONSTRAINT f_key_cc_cfg_xcloud_facility_addtion_facility_id FOREIGN KEY (facility_id) REFERENCES setting.cc_cfg_facility(facility_id) ON DELETE CASCADE;
ALTER TABLE ONLY setting.cc_cfg_xcloud_facility_addtion
    ADD CONSTRAINT f_key_cc_cfg_xcloud_facility_addtion_cloud_scope_id FOREIGN KEY (cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_scope(cloud_scope_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_facility_addtion_eprop (
    facility_id varchar(512) NOT NULL,
    name varchar(128) NOT NULL,
    data_type varchar(32),
    value varchar(256)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_facility_addtion_eprop
    ADD CONSTRAINT p_key_cc_cfg_xcloud_facility_addtion_eprop PRIMARY KEY (facility_id, name);
ALTER TABLE ONLY setting.cc_cfg_xcloud_facility_addtion_eprop
    ADD CONSTRAINT f_key_cc_cfg_xcloud_facility_addtion_eprop_facility_id FOREIGN KEY (facility_id) REFERENCES setting.cc_cfg_xcloud_facility_addtion(facility_id) ON DELETE CASCADE;

CREATE TABLE IF NOT EXISTS setting.cc_cfg_xcloud_login_user (
    cloud_scope_id varchar(64) NOT NULL,
    cloud_login_user_id varchar(64) NOT NULL,
    user_name varchar(256) NOT NULL,
    description varchar(256),
    cloud_user_type varchar(64) NOT NULL,
    priority integer NOT NULL,
    reg_date timestamp without time zone,
    update_date timestamp without time zone,
    reg_user varchar(64),
    update_user varchar(64)
    );
ALTER TABLE ONLY setting.cc_cfg_xcloud_login_user
    ADD CONSTRAINT p_key_cc_cfg_xcloud_login_user PRIMARY KEY (cloud_scope_id, cloud_login_user_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_login_user
    ADD CONSTRAINT f_key_cc_cfg_xcloud_login_user_scope FOREIGN KEY (cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_scope(cloud_scope_id) ON DELETE CASCADE;
ALTER TABLE ONLY setting.cc_cfg_xcloud_scope
    ADD CONSTRAINT f_key_cc_cfg_xcloud_scope_cloud_scope_id_account_id FOREIGN KEY (cloud_scope_id, account_id) REFERENCES setting.cc_cfg_xcloud_login_user(cloud_scope_id, cloud_login_user_id) ON DELETE SET NULL;

CREATE TABLE setting.cc_cfg_xcloud_login_user_eprop (
    cloud_scope_id varchar(64) NOT NULL,
    cloud_login_user_id varchar(64) NOT NULL,
    name varchar(128) NOT NULL,
    data_type varchar(32),
    value varchar(256)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_login_user_eprop
    ADD CONSTRAINT p_key_cc_cfg_xcloud_login_user_eprop PRIMARY KEY (cloud_scope_id, cloud_login_user_id, name);
ALTER TABLE ONLY setting.cc_cfg_xcloud_login_user_eprop
    ADD CONSTRAINT f_key_cc_cfg_xcloud_login_user_eprop_cloud_scope_id_cloud_login_user_id FOREIGN KEY (cloud_scope_id, cloud_login_user_id) REFERENCES setting.cc_cfg_xcloud_login_user(cloud_scope_id, cloud_login_user_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_credential_base (
    cloud_login_user_id varchar(64) NOT NULL,
    cloud_scope_id varchar(64) NOT NULL,
    credential_type varchar(64) NOT NULL
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_credential_base
    ADD CONSTRAINT p_key_cc_cfg_xcloud_credential_base PRIMARY KEY (cloud_login_user_id, cloud_scope_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_credential_base
    ADD CONSTRAINT f_key_cc_cfg_xcloud_credential_base_scope_user FOREIGN KEY (cloud_scope_id, cloud_login_user_id) REFERENCES setting.cc_cfg_xcloud_login_user(cloud_scope_id, cloud_login_user_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_credential_accesskey (
    cloud_login_user_id varchar(64) NOT NULL,
    cloud_scope_id varchar(64) NOT NULL,
    access_key varchar(1024) NOT NULL,
    secret_key varchar(8192) NOT NULL
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_credential_accesskey
    ADD CONSTRAINT p_key_cc_cfg_xcloud_credential_accesskey PRIMARY KEY (cloud_login_user_id, cloud_scope_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_credential_accesskey
    ADD CONSTRAINT f_key_cc_cfg_xcloud_credential_accesskey_credential FOREIGN KEY (cloud_login_user_id, cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_credential_base(cloud_login_user_id, cloud_scope_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_credential_user (
    cloud_login_user_id varchar(64) NOT NULL,
    cloud_scope_id varchar(64) NOT NULL,    
    user_name varchar(256) NOT NULL,
    password varchar(1024) NOT NULL
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_credential_user
    ADD CONSTRAINT p_key_cc_cfg_xcloud_credential_user PRIMARY KEY (cloud_login_user_id, cloud_scope_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_credential_user
    ADD CONSTRAINT f_key_cc_cfg_xcloud_credential_user_credential FOREIGN KEY (cloud_login_user_id, cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_credential_base(cloud_login_user_id, cloud_scope_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_role_relation (
    cloud_scope_id varchar(256) NOT NULL,
    cloud_login_user_id varchar(64) NOT NULL,
    role_id varchar(64) NOT NULL
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_role_relation
    ADD CONSTRAINT p_key_cc_cfg_xcloud_role_relation PRIMARY KEY (cloud_scope_id, role_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_role_relation
    ADD CONSTRAINT f_key_cc_cfg_xcloud_role_relation_scopename_accesskey FOREIGN KEY (cloud_scope_id, cloud_login_user_id) REFERENCES setting.cc_cfg_xcloud_login_user(cloud_scope_id, cloud_login_user_id) ON DELETE CASCADE;
ALTER TABLE ONLY setting.cc_cfg_xcloud_role_relation
    ADD CONSTRAINT f_key_cc_cfg_xcloud_role_relation_role FOREIGN KEY (role_id) REFERENCES setting.cc_cfg_role(role_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_private_location (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    location_name varchar(256) NOT NULL
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_private_location
    ADD CONSTRAINT p_key_cc_cfg_xcloud_private_location PRIMARY KEY (cloud_scope_id, location_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_private_location
    ADD CONSTRAINT f_key_cc_cfg_xcloud_private_location_scope FOREIGN KEY (cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_scope(cloud_scope_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_private_endpoint (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    endpoint_id varchar(64) NOT NULL,
    url varchar(256) NOT NULL
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_private_endpoint
    ADD CONSTRAINT p_key_cc_cfg_xcloud_private_endpoint PRIMARY KEY (cloud_scope_id, location_id, endpoint_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_private_endpoint
    ADD CONSTRAINT f_key_cc_cfg_xcloud_private_endpoint_platform_location FOREIGN KEY (cloud_scope_id, location_id) REFERENCES setting.cc_cfg_xcloud_private_location(cloud_scope_id, location_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_task (
    task_key varchar(256) NOT NULL,
    cloud_scope_id varchar(64) NOT NULL,
    class_name varchar(512) NOT NULL,
    saved_data varchar(1024),
    auto_delete_flg smallint NOT NULL,
    option_dependent_flg smallint NOT NULL,
    task_status varchar(32),
    update_date timestamp without time zone
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_task
    ADD CONSTRAINT p_key_cc_cfg_xcloud_task PRIMARY KEY (task_key);
ALTER TABLE ONLY setting.cc_cfg_xcloud_task
    ADD CONSTRAINT f_key_cc_cfg_xcloud_task_cloud_scope_id FOREIGN KEY (cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_scope(cloud_scope_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_location_resource (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    resource_id varchar(256) NOT NULL,
    resource_type varchar(64) NOT NULL,
    reg_date timestamp without time zone,
    update_date timestamp without time zone,
    reg_user varchar(64),
    update_user varchar(64)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_location_resource
    ADD CONSTRAINT p_key_cc_cfg_xcloud_location_resource PRIMARY KEY (cloud_scope_id, location_id, resource_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_location_resource
    ADD CONSTRAINT f_key_cc_cfg_xcloud_location_resource_cloud_scope_id FOREIGN KEY (cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_scope(cloud_scope_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_location_resource_eprop (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    resource_id varchar(256) NOT NULL,
    name varchar(128) NOT NULL,
    data_type varchar(32),
    value varchar(256)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_location_resource_eprop
    ADD CONSTRAINT p_key_cc_cfg_xcloud_location_resource_eprop PRIMARY KEY (cloud_scope_id, location_id, resource_id, name);
ALTER TABLE ONLY setting.cc_cfg_xcloud_location_resource_eprop
    ADD CONSTRAINT f_key_cc_cfg_xcloud_location_resource_eprop_cloud_scope_id_location_id_resource_id FOREIGN KEY (cloud_scope_id, location_id, resource_id) REFERENCES setting.cc_cfg_xcloud_location_resource(cloud_scope_id, location_id, resource_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_facility_location_resource (
    facility_id varchar(512) NOT NULL,
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    resource_id varchar(256) NOT NULL
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_facility_location_resource
    ADD CONSTRAINT p_key_cc_cfg_xcloud_facility_location_resource PRIMARY KEY (facility_id, cloud_scope_id, location_id, resource_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_facility_location_resource
    ADD CONSTRAINT f_key_cc_cfg_xcloud_facility_location_resource_facility_id FOREIGN KEY (facility_id) REFERENCES setting.cc_cfg_xcloud_facility_addtion(facility_id) ON DELETE CASCADE;
ALTER TABLE ONLY setting.cc_cfg_xcloud_facility_location_resource
    ADD CONSTRAINT f_key_cc_cfg_xcloud_facility_location_resource_cloud_scope_id_location_id_resource_id FOREIGN KEY (cloud_scope_id, location_id, resource_id) REFERENCES setting.cc_cfg_xcloud_location_resource(cloud_scope_id, location_id, resource_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_instance (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    resource_id varchar(64) NOT NULL,
    instance_name varchar(64),
    facility_id varchar(512),
    instance_status varchar(64) NOT NULL,
    platform varchar(64),
    instance_status_as_platform varchar(64) NOT NULL,
    resource_type_as_platform varchar(64) NOT NULL,
    ip_addresses varchar(128),
    memo text
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_instance
    ADD CONSTRAINT p_key_cc_cfg_xcloud_instance PRIMARY KEY (cloud_scope_id, location_id, resource_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_instance
    ADD CONSTRAINT f_key_cc_cfg_xcloud_location_resource_cloud_scope_id_location_id_resource_id FOREIGN KEY (cloud_scope_id, location_id, resource_id) REFERENCES setting.cc_cfg_xcloud_location_resource (cloud_scope_id, location_id, resource_id) ON DELETE CASCADE;
ALTER TABLE ONLY setting.cc_cfg_xcloud_instance
    ADD CONSTRAINT f_key_cc_cfg_xcloud_instance_scope FOREIGN KEY (cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_scope(cloud_scope_id) ON DELETE CASCADE;
ALTER TABLE ONLY setting.cc_cfg_xcloud_instance
    ADD CONSTRAINT u_key_cc_cfg_xcloud_instance_facility_id UNIQUE (facility_id);

CREATE TABLE setting.cc_cfg_xcloud_instance_tag (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    instance_id varchar(64) NOT NULL,
    tag_type varchar(64) NOT NULL,
    key varchar(128) NOT NULL,
    value varchar(256)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_instance_tag
    ADD CONSTRAINT p_key_cc_cfg_xcloud_instance_tag PRIMARY KEY (cloud_scope_id, location_id, instance_id, key);
ALTER TABLE ONLY setting.cc_cfg_xcloud_instance_tag
    ADD CONSTRAINT f_key_cc_cfg_xcloud_instance_scope FOREIGN KEY (cloud_scope_id, location_id, instance_id) REFERENCES setting.cc_cfg_xcloud_instance(cloud_scope_id, location_id, resource_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_instance_backup (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    instance_id varchar(64) NOT NULL,
    reg_date timestamp without time zone,
    update_date timestamp without time zone,
    reg_user varchar(64),
    update_user varchar(64)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_instance_backup
    ADD CONSTRAINT p_key_cc_cfg_xcloud_instance_backup PRIMARY KEY (cloud_scope_id, location_id, instance_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_instance_backup
    ADD CONSTRAINT f_key_cc_cfg_xcloud_instance_backup_cloud_scope_id FOREIGN KEY (cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_scope(cloud_scope_id) ON DELETE CASCADE;
ALTER TABLE ONLY setting.cc_cfg_xcloud_instance_backup
    ADD CONSTRAINT f_key_cc_cfg_xcloud_instance_backup_cloud_scope_id_location_id_instance_id FOREIGN KEY (cloud_scope_id, location_id, instance_id) REFERENCES setting.cc_cfg_xcloud_instance(cloud_scope_id, location_id, resource_id) ON DELETE CASCADE;
    
CREATE TABLE setting.cc_cfg_xcloud_instance_backup_entry (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    instance_id varchar(64) NOT NULL,
    entry_id varchar(256) NOT NULL,
    name varchar(128) NOT NULL,
    description varchar(512),
    status varchar(64) NOT NULL,
    status_detail varchar(128),
    create_time timestamp without time zone,
    reg_date timestamp without time zone,
    reg_user varchar(64)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_instance_backup_entry
    ADD CONSTRAINT p_key_cc_cfg_xcloud_instance_backup_entry PRIMARY KEY (cloud_scope_id, location_id, instance_id, entry_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_instance_backup_entry
    ADD CONSTRAINT f_key_cc_cfg_xcloud_instance_backup_entry_cloud_scope_id FOREIGN KEY (cloud_scope_id, location_id, instance_id) REFERENCES setting.cc_cfg_xcloud_instance_backup(cloud_scope_id, location_id, instance_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_instance_backup_data (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    instance_id varchar(64) NOT NULL,
    entry_id varchar(512) NOT NULL,
    name varchar(128) NOT NULL,
    value varchar(256)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_instance_backup_data
    ADD CONSTRAINT p_key_cc_cfg_xcloud_instance_backup_data PRIMARY KEY (cloud_scope_id, location_id, instance_id, entry_id, name);
ALTER TABLE ONLY setting.cc_cfg_xcloud_instance_backup_data
    ADD CONSTRAINT f_key_cc_cfg_xcloud_instance_backup_data_cloud_scope_id_location_id_instance_id FOREIGN KEY (cloud_scope_id, location_id, instance_id) REFERENCES setting.cc_cfg_xcloud_instance_backup(cloud_scope_id, location_id, instance_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_auto_assigne_node_pattern_entry (
    cloud_scope_id varchar(64) NOT NULL,
    scope_id varchar(64) NOT NULL,
    priority int NOT NULL,
    pattern_type varchar(64) NOT NULL,
    pattern varchar(256) NOT NULL
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_auto_assigne_node_pattern_entry
    ADD CONSTRAINT p_key_cc_cfg_xcloud_auto_assigne_node_pattern_entry PRIMARY KEY (cloud_scope_id, priority);
ALTER TABLE ONLY setting.cc_cfg_xcloud_auto_assigne_node_pattern_entry
    ADD CONSTRAINT f_key_cc_cfg_xcloud_auto_assigne_node_pattern_entry_cloud_scope_id FOREIGN KEY (cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_scope(cloud_scope_id) ON DELETE CASCADE;
ALTER TABLE ONLY setting.cc_cfg_xcloud_auto_assigne_node_pattern_entry
    ADD CONSTRAINT f_key_cc_cfg_xcloud_auto_assigne_node_pattern_entry_scope_id FOREIGN KEY (scope_id) REFERENCES setting.cc_cfg_facility(facility_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_entity (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    resource_id varchar(64) NOT NULL,
    entity_name varchar(64) NOT NULL,
    entity_type varchar(64) NOT NULL,
    platform_entity_id varchar(64) NOT NULL,
    facility_id varchar(512)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_entity
    ADD CONSTRAINT p_key_cc_cfg_xcloud_entity PRIMARY KEY (cloud_scope_id, location_id, resource_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_entity
    ADD CONSTRAINT f_key_cc_cfg_xcloud_entity FOREIGN KEY (cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_scope(cloud_scope_id) ON DELETE CASCADE;
ALTER TABLE ONLY setting.cc_cfg_xcloud_entity
    ADD CONSTRAINT f_key_cc_cfg_xcloud_entity_facility_id FOREIGN KEY (facility_id) REFERENCES setting.cc_cfg_node(facility_id) ON DELETE SET NULL;
ALTER TABLE ONLY setting.cc_cfg_xcloud_entity
    ADD CONSTRAINT u_key_cc_cfg_xcloud_entity_facility_id UNIQUE (facility_id);

CREATE TABLE setting.cc_cfg_xcloud_storage (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    resource_id varchar(256) NOT NULL,
    storage_name varchar(128),
    storage_type varchar(64),
    size integer,
    target_instance_id varchar(64),
    target_facility_id varchar(512),
    device_index integer,
    device_type varchar(32),
    device_name varchar(128),
    storage_status varchar(64) NOT NULL,
    storage_status_as_platform varchar(64) NOT NULL,
    resource_type_as_platform varchar(64) NOT NULL
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_storage
    ADD CONSTRAINT p_key_cc_cfg_xcloud_storage PRIMARY KEY (cloud_scope_id, location_id, resource_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_storage
    ADD CONSTRAINT f_key_cc_cfg_xcloud_storage_cloud_scope FOREIGN KEY (cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_scope(cloud_scope_id) ON DELETE CASCADE;
ALTER TABLE ONLY setting.cc_cfg_xcloud_storage
    ADD CONSTRAINT f_key_cc_cfg_xcloud_storage_target_facility_id FOREIGN KEY (target_facility_id) REFERENCES setting.cc_cfg_node(facility_id) ON DELETE SET NULL;

CREATE TABLE setting.cc_cfg_xcloud_storage_backup (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    storage_id varchar(256) NOT NULL,
    reg_date timestamp without time zone,
    update_date timestamp without time zone,
    reg_user varchar(64),
    update_user varchar(64)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_storage_backup
    ADD CONSTRAINT p_key_cc_cfg_xcloud_storage_backup PRIMARY KEY (cloud_scope_id, location_id, storage_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_storage_backup
    ADD CONSTRAINT f_key_cc_cfg_xcloud_storage_backup_cloud_scope_id FOREIGN KEY (cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_scope(cloud_scope_id) ON DELETE CASCADE;
ALTER TABLE ONLY setting.cc_cfg_xcloud_storage_backup
    ADD CONSTRAINT f_key_cc_cfg_xcloud_storage_backup_cloud_scope_id_location_id_storage_id FOREIGN KEY (cloud_scope_id, location_id, storage_id) REFERENCES setting.cc_cfg_xcloud_storage(cloud_scope_id, location_id, resource_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_storage_backup_entry (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    storage_id varchar(256) NOT NULL,
    entry_id varchar(512) NOT NULL,
    name varchar(128) NOT NULL,
    description varchar(512),
    status varchar(64) NOT NULL,
    status_detail varchar(128),
    backup_data_group_id integer,
    create_time timestamp without time zone,
    reg_date timestamp without time zone,
    reg_user varchar(64)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_storage_backup_entry
    ADD CONSTRAINT p_key_cc_cfg_xcloud_storage_backup_entry PRIMARY KEY (cloud_scope_id, location_id, storage_id, entry_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_storage_backup_entry
    ADD CONSTRAINT f_key_cc_cfg_xcloud_storage_backup_entry_cloud_scope_id FOREIGN KEY (cloud_scope_id, location_id, storage_id) REFERENCES setting.cc_cfg_xcloud_storage_backup(cloud_scope_id, location_id, storage_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_storage_backup_data (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    storage_id varchar(256) NOT NULL,
    entry_id varchar(512) NOT NULL,
    name varchar(128) NOT NULL,
    value varchar(256)
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_storage_backup_data
    ADD CONSTRAINT p_key_cc_cfg_xcloud_storage_backup_data PRIMARY KEY (cloud_scope_id, location_id, storage_id, entry_id, name);
ALTER TABLE ONLY setting.cc_cfg_xcloud_storage_backup_data
    ADD CONSTRAINT f_key_cc_cfg_xcloud_storage_backup_data_cloud_scope_id_location_id_storage_id FOREIGN KEY (cloud_scope_id, location_id, storage_id) REFERENCES setting.cc_cfg_xcloud_storage_backup(cloud_scope_id, location_id, storage_id) ON DELETE CASCADE;

CREATE TABLE log.cc_xcloud_platform_area_service_condition (
    cloud_platform_id varchar(64) NOT NULL,
    location_id varchar(64) NOT NULL,
    service_id varchar(64) NOT NULL,
    service_name varchar(64),
    message varchar(256),
    detail varchar(1024),
    status varchar(64) NOT NULL,
    begin_date timestamp without time zone,
    last_date timestamp without time zone,
    record_date timestamp without time zone
);
ALTER TABLE ONLY log.cc_xcloud_platform_area_service_condition
    ADD CONSTRAINT p_key_cc_xcloud_platform_area_service_condition PRIMARY KEY (cloud_platform_id, location_id, service_id);
ALTER TABLE ONLY log.cc_xcloud_platform_area_service_condition
    ADD CONSTRAINT f_key_cc_xcloud_platform_area_service_condition_cloud_scope FOREIGN KEY (cloud_platform_id) REFERENCES setting.cc_cfg_xcloud_platform(cloud_platform_id) ON DELETE CASCADE;

CREATE TABLE log.cc_xcloud_cloudscope_area_service_condition (
    cloud_scope_id varchar(64) NOT NULL,
    location_id varchar(64),
    service_id varchar(64) NOT NULL,
    service_name varchar(64),
    message varchar(256),
    detail varchar(1024),
    status varchar(64) NOT NULL,
    begin_date timestamp without time zone,
    last_date timestamp without time zone,
    record_date timestamp without time zone
);
ALTER TABLE ONLY log.cc_xcloud_cloudscope_area_service_condition
    ADD CONSTRAINT p_key_cc_xcloud_cloudscope_area_service_condition PRIMARY KEY (cloud_scope_id, location_id, service_id);
ALTER TABLE ONLY log.cc_xcloud_cloudscope_area_service_condition
    ADD CONSTRAINT f_key_cc_xcloud_cloudscope_area_service_condition_cloud_scope FOREIGN KEY (cloud_scope_id) REFERENCES setting.cc_cfg_xcloud_scope(cloud_scope_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_billing_alarm (
    plugin_id varchar(64) NOT NULL,
    alarm_id varchar(64) NOT NULL,
    alarm_name varchar(128) NOT NULL,
    description varchar(256),
    owner_role_id varchar(64) NOT NULL,
    facility_id varchar(512) NOT NULL,
    monitor_kind varchar(64) NOT NULL,
    threshold_info_limit double precision,
    threshold_warn_limit double precision,
    notify_group_id varchar(1024) NOT NULL,
    unit varchar(64) NOT NULL,
    application varchar(64) NOT NULL,
    last_notified_day timestamp without time zone,
    reg_date timestamp without time zone,
    update_date timestamp without time zone,
    reg_user varchar(64),
    update_user varchar(64),
    valid_flg smallint,
    collect_flg smallint
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_billing_alarm
    ADD CONSTRAINT p_key_cc_cfg_xcloud_billing_alarm PRIMARY KEY (alarm_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_billing_alarm
    ADD CONSTRAINT f_key_cc_cfg_xcloud_billing_alarm_owner_role_id FOREIGN KEY (owner_role_id) REFERENCES setting.cc_cfg_role(role_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_billing_alarm
    ADD CONSTRAINT f_key_cc_cfg_xcloud_billing_alarm_facility_id FOREIGN KEY (facility_id) REFERENCES setting.cc_cfg_facility(facility_id) ON DELETE CASCADE;

CREATE TABLE setting.cc_cfg_xcloud_billing_detail (
    billing_detail_id serial NOT NULL,
    cloud_scope_id character varying(64) NOT NULL,
    cloud_scope_name character varying(256) NOT NULL,
    target_date date NOT NULL,
    resource_id varchar(1024),
    category character varying(64) NOT NULL,
    category_detail character varying(128),
    display_name character varying(1024) NOT NULL,
    cost numeric,
    unit character varying(64) NOT NULL
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_billing_detail
    ADD CONSTRAINT p_key_cc_cfg_xcloud_billing_detail PRIMARY KEY (billing_detail_id);

CREATE TABLE setting.cc_cfg_xcloud_billing_detail_relation (
    relation_id serial NOT NULL,
    billing_detail_id integer NOT NULL,
    facility_id character varying(512) NOT NULL,
    facility_name character varying(128),
    relation_type character varying(64) NOT NULL
);
ALTER TABLE ONLY setting.cc_cfg_xcloud_billing_detail_relation
    ADD CONSTRAINT p_key_cc_cfg_xcloud_billing_detail_relation PRIMARY KEY (relation_id);
ALTER TABLE ONLY setting.cc_cfg_xcloud_billing_detail_relation
    ADD CONSTRAINT f_key_cc_cfg_xcloud_billing_detail_relation_billing_detail_id FOREIGN KEY (billing_detail_id) REFERENCES setting.cc_cfg_xcloud_billing_detail(billing_detail_id) ON DELETE CASCADE;
